# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ContextLabelWithIdInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'context_label_id': 'str',
        'datum_id': 'str',
        'end_time': 'str',
        'label_id': 'str',
        'source': 'ContextSourceInputV1',
        'start_time': 'str',
        'table_id': 'str'
    }

    attribute_map = {
        'context_label_id': 'contextLabelId',
        'datum_id': 'datumId',
        'end_time': 'endTime',
        'label_id': 'labelId',
        'source': 'source',
        'start_time': 'startTime',
        'table_id': 'tableId'
    }

    def __init__(self, context_label_id=None, datum_id=None, end_time=None, label_id=None, source=None, start_time=None, table_id=None):
        """
        ContextLabelWithIdInputV1 - a model defined in Swagger
        """

        self._context_label_id = None
        self._datum_id = None
        self._end_time = None
        self._label_id = None
        self._source = None
        self._start_time = None
        self._table_id = None

        if context_label_id is not None:
          self.context_label_id = context_label_id
        if datum_id is not None:
          self.datum_id = datum_id
        if end_time is not None:
          self.end_time = end_time
        if label_id is not None:
          self.label_id = label_id
        if source is not None:
          self.source = source
        if start_time is not None:
          self.start_time = start_time
        if table_id is not None:
          self.table_id = table_id

    @property
    def context_label_id(self):
        """
        Gets the context_label_id of this ContextLabelWithIdInputV1.
        If provided, the ID of an existing context label to update

        :return: The context_label_id of this ContextLabelWithIdInputV1.
        :rtype: str
        """
        return self._context_label_id

    @context_label_id.setter
    def context_label_id(self, context_label_id):
        """
        Sets the context_label_id of this ContextLabelWithIdInputV1.
        If provided, the ID of an existing context label to update

        :param context_label_id: The context_label_id of this ContextLabelWithIdInputV1.
        :type: str
        """

        self._context_label_id = context_label_id

    @property
    def datum_id(self):
        """
        Gets the datum_id of this ContextLabelWithIdInputV1.
        If provided, the ID of a more specific aspect of the Item to associate with the label, such as the ID of a capsule

        :return: The datum_id of this ContextLabelWithIdInputV1.
        :rtype: str
        """
        return self._datum_id

    @datum_id.setter
    def datum_id(self, datum_id):
        """
        Sets the datum_id of this ContextLabelWithIdInputV1.
        If provided, the ID of a more specific aspect of the Item to associate with the label, such as the ID of a capsule

        :param datum_id: The datum_id of this ContextLabelWithIdInputV1.
        :type: str
        """

        self._datum_id = datum_id

    @property
    def end_time(self):
        """
        Gets the end_time of this ContextLabelWithIdInputV1.
        The end time of the label in the form of an ISO8601 timestamp. If provided, start time must also be provided.

        :return: The end_time of this ContextLabelWithIdInputV1.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ContextLabelWithIdInputV1.
        The end time of the label in the form of an ISO8601 timestamp. If provided, start time must also be provided.

        :param end_time: The end_time of this ContextLabelWithIdInputV1.
        :type: str
        """

        self._end_time = end_time

    @property
    def label_id(self):
        """
        Gets the label_id of this ContextLabelWithIdInputV1.
        The ID of the label

        :return: The label_id of this ContextLabelWithIdInputV1.
        :rtype: str
        """
        return self._label_id

    @label_id.setter
    def label_id(self, label_id):
        """
        Sets the label_id of this ContextLabelWithIdInputV1.
        The ID of the label

        :param label_id: The label_id of this ContextLabelWithIdInputV1.
        :type: str
        """

        self._label_id = label_id

    @property
    def source(self):
        """
        Gets the source of this ContextLabelWithIdInputV1.

        :return: The source of this ContextLabelWithIdInputV1.
        :rtype: ContextSourceInputV1
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this ContextLabelWithIdInputV1.

        :param source: The source of this ContextLabelWithIdInputV1.
        :type: ContextSourceInputV1
        """

        self._source = source

    @property
    def start_time(self):
        """
        Gets the start_time of this ContextLabelWithIdInputV1.
        The start time of the label in the form of an ISO8601 timestamp. If provided, end time must also be provided.

        :return: The start_time of this ContextLabelWithIdInputV1.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ContextLabelWithIdInputV1.
        The start time of the label in the form of an ISO8601 timestamp. If provided, end time must also be provided.

        :param start_time: The start_time of this ContextLabelWithIdInputV1.
        :type: str
        """

        self._start_time = start_time

    @property
    def table_id(self):
        """
        Gets the table_id of this ContextLabelWithIdInputV1.
        If provided, the ID of the Table Definition that will be used for permissions checking. The user needs read permissions on the provided table definition and theitem has to be in the table in order to create, update, or delete context. If not provided, the user must have read permissions on the item id the context is being applied to.

        :return: The table_id of this ContextLabelWithIdInputV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this ContextLabelWithIdInputV1.
        If provided, the ID of the Table Definition that will be used for permissions checking. The user needs read permissions on the provided table definition and theitem has to be in the table in order to create, update, or delete context. If not provided, the user must have read permissions on the item id the context is being applied to.

        :param table_id: The table_id of this ContextLabelWithIdInputV1.
        :type: str
        """

        self._table_id = table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ContextLabelWithIdInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.118.2-v202603221428-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConfigurationOptionOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _advanced: bool
    _allowed_values: Optional[str]
    _default_dependencies: Optional[List[str]]
    _default_description: Optional[str]
    _default_value: Any
    _description: str
    _modifiable: bool
    _note: Optional[str]
    _path: str
    _registration: Optional[str]
    _registration_description: Optional[str]
    _units: Optional[str]
    _value: Optional[Any]


    def __init__(
        self,
        advanced: Optional[bool] = False,
        allowed_values: Optional[str] = None,
        default_dependencies: Optional[List[str]] = None,
        default_description: Optional[str] = None,
        default_value: Optional[Any] = None,
        description: Optional[str] = None,
        modifiable: Optional[bool] = False,
        note: Optional[str] = None,
        path: Optional[str] = None,
        registration: Optional[str] = None,
        registration_description: Optional[str] = None,
        units: Optional[str] = None,
        value: Optional[Any] = None,
    ) -> None: ...

    @property
    def advanced(self) -> bool: ...

    @advanced.setter
    def advanced(self, advanced: bool) -> None: ...

    @property
    def allowed_values(self) -> Optional[str]: ...

    @allowed_values.setter
    def allowed_values(self, allowed_values: Optional[str]) -> None: ...

    @property
    def default_dependencies(self) -> Optional[List[str]]: ...

    @default_dependencies.setter
    def default_dependencies(self, default_dependencies: Optional[List[str]]) -> None: ...

    @property
    def default_description(self) -> Optional[str]: ...

    @default_description.setter
    def default_description(self, default_description: Optional[str]) -> None: ...

    @property
    def default_value(self) -> Any: ...

    @default_value.setter
    def default_value(self, default_value: Any) -> None: ...

    @property
    def description(self) -> str: ...

    @description.setter
    def description(self, description: str) -> None: ...

    @property
    def modifiable(self) -> bool: ...

    @modifiable.setter
    def modifiable(self, modifiable: bool) -> None: ...

    @property
    def note(self) -> Optional[str]: ...

    @note.setter
    def note(self, note: Optional[str]) -> None: ...

    @property
    def path(self) -> str: ...

    @path.setter
    def path(self, path: str) -> None: ...

    @property
    def registration(self) -> Optional[str]: ...

    @registration.setter
    def registration(self, registration: Optional[str]) -> None: ...

    @property
    def registration_description(self) -> Optional[str]: ...

    @registration_description.setter
    def registration_description(self, registration_description: Optional[str]) -> None: ...

    @property
    def units(self) -> Optional[str]: ...

    @units.setter
    def units(self, units: Optional[str]) -> None: ...

    @property
    def value(self) -> Optional[Any]: ...

    @value.setter
    def value(self, value: Optional[Any]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
